@@ -79,6 +79,7 @@ import itertools
 import inspect
 import sys
 
+from abc import ABC, abstractmethod
 from pathlib import Path
 from argparse import ArgumentTypeError
 from contextlib import suppress
@@ -196,6 +197,10 @@ class PythonExpression:
 
 
 class SliceAgain(LazyEvaluation):
+    """
+    Raised by `refinery.lib.argformats.sliceobj` to indicate that meta variables
+    are required to compue this slice.
+    """
     def __init__(self, expr):
         self.expr = expr
 
@@ -609,7 +614,7 @@ class DelayedArgument(LazyEvaluation):
             return obj
         raise ArgumentTypeError(F'The meta variable {name} is of type {type(obj).__name__} and no conversion is known.')
 
-    @handler.register('var', final=True)
+    @handler.register('var', '?', final=True)
     def var(self, name: str) -> bytes:
         """
         The final handler `var:name` contains the value of the meta variable `name`.
@@ -624,7 +629,7 @@ class DelayedArgument(LazyEvaluation):
             return self._interpret_variable(name, result)
         return extract
 
-    @handler.register('xvar', final=True)
+    @handler.register('xvar', '!', final=True)
     def xvar(self, name: str) -> bytes:
         """
         The final handler `xvar:name` contains the value of the meta variable `name`.
@@ -783,11 +788,11 @@ class DelayedArgument(LazyEvaluation):
         Instead of a Python expression, the  variable `update` can also be one of the following values, which
         are pre-defined update routines based on popular generators:
 
-        - `$libc`: `A * 0x041C64E6D + 0x003039 # (A >> 0x00) & 0x3FFFFFFF`
-        - `$ansi`: `A * 0x041C64E6D + 0x003039 # (A >> 0x10) & 0x00003FFF`
-        - `$msvc`: `A * 0x0000343FD + 0x269EC3 # (A >> 0x10) & 0x00003FFF`
+        - `$libc`: `A * 0x041C64E6D + 0x003039`
+        - `$ansi`: `A * 0x041C64E6D + 0x003039 # (A >> 0x10)`
+        - `$msvc`: `A * 0x0000343FD + 0x269EC3 # (A >> 0x10)`
         - `$msvb`: `A * 0x043FD43FD + 0xC39EC3`
-        - `$java`: `A * 0x5DEECE66D + 0x00000B # (A >> 0x10) & 0x7FFFFFFF`
+        - `$java`: `A * 0x5DEECE66D + 0x00000B`
         - `$mmix`: `A * 6364136223846793005 + 1442695040888963407`
         """
         if spec.startswith('$'):
@@ -1134,14 +1139,38 @@ def regexp(expression: str) -> Union[int, bytes, DelayedRegexpArgument]:
     return arg
 
 
+class Option(ABC):
+    name: str
+    mode: Any
+
+    @abstractmethod
+    def __init__(self, name: str):
+        raise NotImplementedError
+
+    def __eq__(self, other):
+        return str(other) == self.name
+
+    def __hash__(self):
+        return hash(self.name)
+
+    def __str__(self):
+        return self.name
+
+    def __repr__(self):
+        return self.name
+
+    @property
+    def value(self):
+        return self.mode
+
+
 def OptionFactory(options: Mapping[str, Any], ignorecase: bool = False):
     """
     The factory produces an argument parser type that accepts the keys of `options`
     as possible values and causes the parsed argument to contain the corresponding
     value from the `options` dictionary.
     """
-
-    class Option():
+    class _Option(Option):
         def __init__(self, name: str):
             if ignorecase and name not in options:
                 needle = name.upper()
@@ -1154,23 +1183,7 @@ def OptionFactory(options: Mapping[str, Any], ignorecase: bool = False):
             self.mode = options[name]
             self.name = name
 
-        def __eq__(self, other):
-            return str(other) == self.name
-
-        def __hash__(self):
-            return hash(self.name)
-
-        def __str__(self):
-            return self.name
-
-        def __repr__(self):
-            return self.name
-
-        @property
-        def value(self):
-            return self.mode
-
-    return Option
+    return _Option
 
 
 def extract_options(symbols, prefix='MODE_', *exceptions):
