@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+from __future__ import annotations
 from typing import ByteString, Callable, Dict, List, Optional, Set, Union
 
 import marshal
@@ -14,25 +15,11 @@ import contextlib
 import dataclasses
 import sys
 
-try:
-    import xdis.load
-    import xdis.magics
-    import xdis.marsh
-    from importlib.util import MAGIC_NUMBER
-except ImportError:
-    pass
-else:
-    A, B, C, *_ = sys.version_info
-    V = F'{A}.{B}.{C}'
-    if V not in xdis.magics.canonic_python_version:
-        xdis.magics.add_canonic_versions(V, F'{A}.{B}')
-    del A, B, C, V
+from importlib.util import MAGIC_NUMBER
 
-from uncompyle6.main import decompile, iscode
-
-from . import arg, ArchiveUnit
-from ....lib.structures import EOF, MemoryFile, StreamDetour, Struct, StructReader
-from ....units.pattern.carve import carve
+from refinery.units.formats.archive import arg, ArchiveUnit
+from refinery.units.pattern.carve import carve
+from refinery.lib.structures import EOF, MemoryFile, StreamDetour, Struct, StructReader
 
 from Crypto.Cipher import AES
 
@@ -47,23 +34,6 @@ def version2tuple(version: str):
     return tuple(int(k, 10) for k in re.fullmatch(R'^(\d+\.\d+(?:\.\d+)?)(.*)$', version).group(1).split('.'))
 
 
-def contains_code(buffer) -> bool:
-    # xdis unmarshal prints directly to stderr; silence it:
-    sys_stderr = sys.stderr
-    sys.stderr = open(os.devnull, 'w')
-    try:
-        module_data = xdis.load.load_module_from_file_object(MemoryFile(buffer))
-    except Exception:
-        return False
-    else:
-        code = module_data[3]
-        if not isinstance(code, list):
-            code = [code]
-        return code and all(iscode(c) for c in code)
-    finally:
-        sys.stderr = sys_stderr
-
-
 def decompress_peek(buffer, size=512) -> Optional[bytes]:
     try:
         return zlib.decompressobj().decompress(buffer[:size])
@@ -77,7 +47,7 @@ def decompile_buffer(buffer: ByteString, file_name: str) -> ByteString:
     sys.stderr = open(os.devnull, 'w')
     try:
         version, timestamp, magic_int, codez, is_pypy, _, _ = \
-            xdis.load.load_module_from_file_object(MemoryFile(buffer), file_name, code_objects)
+            xtpyi._xdis.load.load_module_from_file_object(MemoryFile(buffer), file_name, code_objects)
     finally:
         sys.stderr = sys_stderr
     if not isinstance(codez, list):
@@ -87,7 +57,7 @@ def decompile_buffer(buffer: ByteString, file_name: str) -> ByteString:
     with io.TextIOWrapper(decompiled, xtpyi.codec, newline='') as output:
         for code in codez:
             try:
-                decompile(
+                xtpyi._uncompyle6.main.decompile(
                     version,
                     code,
                     output,
@@ -180,7 +150,7 @@ class PYZ(Struct):
             raise ValueError('invalid magic')
         magic = bytes(reader.read(4))
         with contextlib.suppress(KeyError):
-            version = xdis.magics.versions[magic]
+            version = xtpyi._xdis.magics.versions[magic]
         vtuple = version2tuple(version)
         padding_size = 4
         if vtuple >= (3, 3):
@@ -200,17 +170,17 @@ class PYZ(Struct):
             toc = marshal.loads(toc_data)
         except Exception as error:
             if MAGIC_NUMBER != self.magic[:4]:
-                _ord = xdis.marsh.Ord
-                xdis.marsh.Ord = ord  # monkey-patch workaround for bug in xdis
+                _ord = xtpyi._xdis.marsh.Ord
+                xtpyi._xdis.marsh.Ord = ord  # monkey-patch workaround for bug in xdis
                 try:
-                    toc = xdis.marsh.load(
+                    toc = xtpyi._xdis.marsh.load(
                         MemoryFile(self.data), self.version)
                 except Exception:
                     pass
                 else:
                     error = None
                 finally:
-                    xdis.marsh.Ord = _ord
+                    xtpyi._xdis.marsh.Ord = _ord
             if error is not None:
                 raise error
 
@@ -481,6 +451,25 @@ class xtpyi(ArchiveUnit):
             unmarshal=unmarshal, user_code=user_code
         )
 
+    @ArchiveUnit.Requires('xdis', optional=False)
+    def _xdis():
+        import xdis.load
+        import xdis.magics
+        import xdis.marsh
+        import xdis
+        A, B, C, *_ = sys.version_info
+        V = F'{A}.{B}.{C}'
+        if V not in xdis.magics.canonic_python_version:
+            xdis.magics.add_canonic_versions(V, F'{A}.{B}')
+        del A, B, C, V
+        return xdis
+
+    @ArchiveUnit.Requires('uncompyle6', optional=False)
+    def _uncompyle6():
+        import uncompyle6
+        import uncompyle6.main
+        return uncompyle6
+
     def unpack(self, data):
         view = memoryview(data)
         positions = [m.start() for m in re.finditer(re.escape(PyInstallerArchiveEpilogue.MagicSignature), view)]
