@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 from struct import unpack
 
-from ... import Unit
+from refinery.units import Unit
 
 
 class carve_zip(Unit):
@@ -11,25 +11,18 @@ class carve_zip(Unit):
     """
 
     def process(self, data):
-
-        def carve(start):
-            end = start
-            while end <= start:
-                end = data.find(B'PK\x05\x06', end + 4)
-                if end < 0:
-                    return None
-                size, offset = unpack('<LL', data[end + 12 : end + 20])
-                if offset + start + size == end:
-                    return end + 22
-
         cursor = 0
-
         while True:
             start = data.find(B'PK', cursor)
             if start < cursor:
                 break
-            end = carve(start)
-            if end is None:
-                break
+            end = data.find(B'PK\x05\x06', start + 4)
+            if end < 0:
+                return None
+            size, offset = unpack('<LL', data[end + 12 : end + 20])
+            if offset + start + size != end:
+                cursor = start + 2
+                continue
+            end += 22
             yield data[start:end]
             cursor = end
